if not PriorityQueue then return end

if select(2, UnitClass('player')) ~= "DEATHKNIGHT" then
	return
end

local L = LibStub("AceLocale-3.0"):GetLocale("PriorityQueue")
local C = PriorityQueue.constants -- Defined in PriorityQueue LUA no locale needed.

-- Single Rune
C["Blood Strike"], _, C["Blood Strike Icon"] = GetSpellInfo(45902)
C["Heart Strike"], _, C["Heart Strike Icon"] = GetSpellInfo(55258)
C["Icy Touch"], _, C["Icy Touch Icon"] = GetSpellInfo(45477)
C["Plague Strike"], _, C["Plague Strike Icon"] = GetSpellInfo(45462)

--Double Rune
C["Death Strike"], _, C["Death Strike Icon"] = GetSpellInfo(49998)
C["Obliterate"], _, C["Obliterate Icon"] = GetSpellInfo(49020)
C["Howling Blast"], _, C["Howling Blast Icon"] = GetSpellInfo(49184)
C["Scourge Strike"], _, C["Scourge Strike Icon"] = GetSpellInfo(55265)

--Multi Rune
C["Death and Decay"], _, C["Death and Decay Icon"] = GetSpellInfo(49998)

-- Rune Power
C["Corpse Explosion"], _, C["Corpse Explosion Icon"] = GetSpellInfo(51327)
C["Death Coil"], _, C["Death Coil Icon"] = GetSpellInfo(52375)
C["Frost Strike"], _, C["Frost Strike Icon"] = GetSpellInfo(51416)
C["Rune Strike"], _, C["Rune Strike Icon"] = GetSpellInfo(56815)
C["Unholy Blight"], _, C["Unholy Blight Icon"] = GetSpellInfo(51376)
C["Dancing Rune Weapon"], _, C["Dancing Rune Weapon Icon"] = GetSpellInfo(49028)

--Diseases
C["Frost Fever"] = GetSpellInfo(55095)
C["Blood Plague"] = GetSpellInfo(55078)

-- Buffs
C["Horn of Winter"], _, C["Horn of Winter Icon"] = GetSpellInfo(57330)

-- Procs
C["Killing Machine"] = GetSpellInfo(51124);
C["Freezing Fog"] = GetSpellInfo(59052);

---------------------------
-- Death Knight Priorities
---------------------------

function PriorityQueue:GetDKPriorityDefaults()
	-- need a function to work out spec for now fixed values
	self.presets.priorities.name["Blood with DS"] =  L["Blood with DS"]
	self.presets.priorities.list["Blood with DS"] = { "HoW", "DRW", "RS", "HS_2D", "DS_2D", "DC", "PS", "IT", "HS", "DS" }
	-- Deprecated rotation as of 3.1.x
	--self.presets.priorities.name["Blood with OB"] =  L["Blood with OB"]
	--self.presets.priorities.list["Blood with OB"] = { "HoW", "DRW", "RS", "HS_2D", "OB_2D", "DC", "PS", "IT", "HS", "OB" }
	self.presets.priorities.name["Frost Tank"] =  L["Frost Tank"]
	self.presets.priorities.list["Frost Tank"] = { "HB", "FS_FF_KM", "OB_FF", "BS", "FS_FF", "none", "none", "none", "none", "none" }
    self.presets.default = "Blood with DS"
end

PriorityQueue.priorityTable.name["DRW"] = C["Dancing Rune Weapon"]
PriorityQueue.priorityTable.icon["DRW"] = C["Dancing Rune Weapon Icon"]
PriorityQueue.priorityTable.test["DRW"] = 
	function () 
		return UnitPower("player") >= 40 and PriorityQueue:SpellAvailable(C["Dancing Rune Weapon"])
	end 

PriorityQueue.priorityTable.name["DC"] = C["Death Coil"]
PriorityQueue.priorityTable.icon["DC"] = C["Death Coil Icon"]
PriorityQueue.priorityTable.test["DC"] = 
	function () 
		return UnitPower("player") >= 40 and PriorityQueue:SpellAvailable(C["Death Coil"])
	end 

PriorityQueue.priorityTable.name["RS"] = C["Rune Strike"]
PriorityQueue.priorityTable.icon["RS"] = C["Rune Strike Icon"]
PriorityQueue.priorityTable.test["RS"] = 
	function () 
		return UnitPower("player") >= 20 and PriorityQueue.events.dodgeparry and PriorityQueue:SpellAvailable(C["Rune Strike"])
	end 

PriorityQueue.priorityTable.name["HS_2D"] = L["HS with 2 diseases"]
PriorityQueue.priorityTable.icon["HS_2D"] = C["Heart Strike Icon"]
PriorityQueue.priorityTable.test["HS_2D"] = 
	function () 
		-- heart strike with at least two diseases on target
		return PriorityQueue:RunesAvailable(1,0,0) and PriorityQueue:GetDiseaseCount() >= 2 and PriorityQueue:SpellAvailable(C["Heart Strike"])
	end 

PriorityQueue.priorityTable.name["HS_1D"] = L["HS with 1+ disease"]
PriorityQueue.priorityTable.icon["HS_1D"] = C["Heart Strike Icon"]
PriorityQueue.priorityTable.test["HS_1D"] = 
	function () 
		-- Heart Strike with at least 1 disease on target
		return PriorityQueue:RunesAvailable(1,0,0) and PriorityQueue:GetDiseaseCount() >= 1 and PriorityQueue:SpellAvailable(C["Heart Strike"])
	end 

PriorityQueue.priorityTable.name["HS"] = C["Heart Strike"]
PriorityQueue.priorityTable.icon["HS"] = C["Heart Strike Icon"]
PriorityQueue.priorityTable.test["HS"] = 
	function () 
		-- heart strike regardless of diseases
		return PriorityQueue:RunesAvailable(1,0,0) and PriorityQueue:SpellAvailable(C["Heart Strike"])
	end 

PriorityQueue.priorityTable.name["BS"] = C["Blood Strike"]
PriorityQueue.priorityTable.icon["BS"] = C["Blood Strike Icon"]
PriorityQueue.priorityTable.test["BS"] = 
	function () 
		return PriorityQueue:RunesAvailable(1,0,0) and PriorityQueue:SpellAvailable(C["Blood Strike"])
	end 

PriorityQueue.priorityTable.name["PS"] = C["Plague Strike"]
PriorityQueue.priorityTable.icon["PS"] = C["Plague Strike Icon"]
PriorityQueue.priorityTable.test["PS"] = 
	function () 
		return PriorityQueue:RunesAvailable(0,0,1) and not PriorityQueue:GetDebuffInfo(C["Blood Plague"]) and PriorityQueue:SpellAvailable(C["Plague Strike"])
	end 

PriorityQueue.priorityTable.name["IT"] = C["Icy Touch"]
PriorityQueue.priorityTable.icon["IT"] = C["Icy Touch Icon"]
PriorityQueue.priorityTable.test["IT"] = 
	function () 
		return PriorityQueue:RunesAvailable(0,1,0) and not PriorityQueue:GetDebuffInfo(C["Frost Fever"]) and PriorityQueue:SpellAvailable(C["Icy Touch"])
	end 

PriorityQueue.priorityTable.name["OB_2D"] = L["OB with 2 diseases"]
PriorityQueue.priorityTable.icon["OB_2D"] = C["Obliterate Icon"]
PriorityQueue.priorityTable.test["OB_2D"] = 
	function () 
		return PriorityQueue:RunesAvailable(0,1,1) and PriorityQueue:GetDiseaseCount() > 1 and PriorityQueue:SpellAvailable(C["Obliterate"])
	end 

PriorityQueue.priorityTable.name["OB"] = C["Obliterate"]
PriorityQueue.priorityTable.icon["OB"] = C["Obliterate Icon"]
PriorityQueue.priorityTable.test["OB"] = 
	function () 
		return PriorityQueue:RunesAvailable(0,1,1) and PriorityQueue:GetDiseaseCount() > 0 and PriorityQueue:SpellAvailable(C["Obliterate"])
	end 

PriorityQueue.priorityTable.name["DS_2D"] = L["DS with 2 diseases"]
PriorityQueue.priorityTable.icon["DS_2D"] = C["Death Strike Icon"]
PriorityQueue.priorityTable.test["DS_2D"] = 
	function () 
		return PriorityQueue:RunesAvailable(0,1,1) and PriorityQueue:GetDiseaseCount() > 1 and PriorityQueue:SpellAvailable(C["Death Strike"])
	end 

PriorityQueue.priorityTable.name["DS"] = C["Death Strike"]
PriorityQueue.priorityTable.icon["DS"] = C["Death Strike Icon"]
PriorityQueue.priorityTable.test["DS"] = 
	function () 
		return PriorityQueue:RunesAvailable(0,1,1) and PriorityQueue:GetDiseaseCount() > 0 and PriorityQueue:SpellAvailable(C["Death Strike"])
	end 

PriorityQueue.priorityTable.name["HoW"] = C["Horn of Winter"]
PriorityQueue.priorityTable.icon["HoW"] = C["Horn of Winter Icon"]
PriorityQueue.priorityTable.test["HoW"] = 
	function () 
		return not PriorityQueue:GetBuffInfo(C["Horn of Winter"]) and PriorityQueue:SpellAvailable( C["Horn of Winter"])
	end

-- Frost Fever-specific priorities; useful for Frost-spec tanking...
PriorityQueue.priorityTable.name["OB_FF"] = L["Obliterate with FF"]
PriorityQueue.priorityTable.icon["OB_FF"] = C["Obliterate Icon"]
PriorityQueue.priorityTable.test["OB_FF"] = 
	function () 
		return PriorityQueue:RunesAvailable(0,1,1) and PriorityQueue:GetDebuffInfo(C["Frost Fever"]) and PriorityQueue:SpellAvailable(C["Obliterate"])
	end

-- NOTE: Presently, these two priority functions assume that Frost Strike is glyphed.
PriorityQueue.priorityTable.name["FS_FF"] = L["Frost Strike with FF"]
PriorityQueue.priorityTable.icon["FS_FF"] = C["Frost Strike Icon"]
PriorityQueue.priorityTable.test["FS_FF"] = 
	function () 
		return UnitPower("player") >= 32 and PriorityQueue:SpellAvailable(C["Frost Strike"]) and PriorityQueue:GetDebuffInfo(C["Frost Fever"]);
	end

PriorityQueue.priorityTable.name["FS_FF_KM"] = L["Frost Strike with FF and KM"]
PriorityQueue.priorityTable.icon["FS_FF_KM"] = C["Frost Strike Icon"]
PriorityQueue.priorityTable.test["FS_FF_KM"] = 
	function ()
		return UnitPower("player") >= 32 and PriorityQueue:SpellAvailable(C["Frost Strike"]) and PriorityQueue:GetDebuffInfo(C["Frost Fever"]) and PriorityQueue:GetBuffInfo(C["Killing Machine"]);
	end

PriorityQueue.priorityTable.name["HB"] = C["Howling Blast"]
PriorityQueue.priorityTable.icon["HB"] = C["Howling Blast Icon"]
PriorityQueue.priorityTable.test["HB"] = 
	function ()
		return  PriorityQueue:SpellAvailable(C["Howling Blast"])  and (PriorityQueue:GetBuffInfo(C["Freezing Fog"]) or PriorityQueue:RunesAvailable(0,1,1));
	end 

----------------------
-- Rune functions --
----------------------
	
function PriorityQueue:RunesAvailable(blood, frost, unholy)
	local numBlood = 0
	local numFrost = 0
	local numUnholy = 0
	local numDeath = 0
	local timeleft = 0
	local numRequired = blood + frost + unholy
	for slot=1, 6 do
		start, duration, runeReady = GetRuneCooldown(slot)
		if start then
			timeleft = start + duration - GetTime()
		end
		if runeReady or timeleft <= PriorityQueue.db.char.priority.cooldown then
			runeType = GetRuneType(slot)
			if (runeType == 1) then
				numBlood = numBlood + 1
			elseif (runeType == 2) then
				numUnholy = numUnholy + 1
			elseif (runeType == 3) then
				numFrost = numFrost + 1
			elseif (runeType == 4) then
				numDeath = numDeath + 1
			end
		end
	end
	--self:DebugPrint("blood : "..numBlood..", frost : "..numFrost.." unholy : "..numUnholy)
	if blood <= numBlood and frost <= numFrost and unholy <= numUnholy then
		return true -- we have enough runes
	end
	if  numDeath >= numRequired then
		return true
	end
	if numRequired == 1 or numDeath == 0 then
		return false  -- we only required 1 rune and didn't have an individual or death rune so clearly fail
	end
	-- at this stage we have 2 or more requrired and need to check indivdual + death
	if numRequired == 2 and numDeath == 1 then
		if (blood == 1 and numBlood >= 1) or (frost == 1 and numFrost >= 1) or (unholy == 1 and numUnholy >= 1) then
			return true -- we have one Death Rune and at least 1 of another and needed two so good to go.
		end
	end
	return false
end	
	
function PriorityQueue:GetDiseaseCount()
	local index = 1
	local diseases = 0
	while UnitDebuff("target", index) do
		local name, _, _, count, debuffType, _, debuffExpires, owner = UnitDebuff("target", index)
        local isMine = (owner == "player");
		if isMine and debuffType == "Disease" then -- don't return true on finding another player's debuff
			local timeleft = debuffExpires - GetTime()
			--self:DebugPrint("found a disease "..name.." time left "..timeleft)
			if timeleft > PriorityQueue.db.char.priority.cooldown then
				diseases = diseases + 1
			end
		end
		index = index + 1
	end
	--self:DebugPrint("target has "..diseases.." of my diseases")
	return diseases
end
