if not PriorityQueue then return end

if select(2, UnitClass('player')) ~= "DRUID" then
	return
end

local L = LibStub("AceLocale-3.0"):GetLocale("PriorityQueue")
local C = PriorityQueue.constants -- Defined in PriorityQueue LUA no locale needed.

C["Swipe"], _, C["Swipe Icon"] = GetSpellInfo(779)
C["Mangle (Cat)"], _, C["Mangle (Cat) Icon"] = GetSpellInfo(48566)
C["Savage Roar"], _, C["Savage Roar Icon"] = GetSpellInfo(52610)
C["Rake"], _, C["Rake Icon"] = GetSpellInfo(1822)
C["Shred"], _, C["Shred Icon"] = GetSpellInfo(5221)
C["Rip"], _, C["Rip Icon"] = GetSpellInfo(1079)
C["Ferocious Bite"], _, C["Ferocious Bite Icon"] = GetSpellInfo(22568)

---------------------------
-- Druid Priorities
---------------------------

function PriorityQueue:GetDruidPriorityDefaults()
	-- need a function to work out spec for now fixed values
	self.presets.priorities.name["Cat"] =  L["Cat"]
	self.presets.priorities.list["Cat"] = { "4cp_sr", "mc",  "5cp_rip", "mc_sr_rake",  "4cp_rip_fb", "sh", "none", "none", "none", "none" }
	self.presets.default = "Cat"
end

PriorityQueue.priorityTable.name["sw"] = C["Swipe"]
PriorityQueue.priorityTable.icon["sw"] = C["Swipe Icon"]
PriorityQueue.priorityTable.test["sw"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Swipe"]) 
	end 

PriorityQueue.priorityTable.name["mc"] = C["Mangle (Cat)"]
PriorityQueue.priorityTable.icon["mc"] = C["Mangle (Cat) Icon"]
PriorityQueue.priorityTable.test["mc"] = 
	function ()
		-- DEBUG: Issues with SpellAvailable() method for Mangle... Hard-coded to assume availability.
		local debuff, duration = PriorityQueue:GetDebuffInfo(C["Mangle (Cat)"])
		return (not debuff or duration <= 1)
		--return (not debuff or duration <= 1) and PriorityQueue:SpellAvailable(C["Mangle (Cat)"])
		--return PriorityQueue:SpellAvailable(C["Mangle (Cat)"])
		
	end

PriorityQueue.priorityTable.name["rake"] = C["Rake"]
PriorityQueue.priorityTable.icon["rake"] = C["Rake Icon"]
PriorityQueue.priorityTable.test["rake"] = 
	function ()
		return not PriorityQueue:GetDebuffInfo(C["Rake"]) and PriorityQueue:SpellAvailable(C["Rake"])
	end

PriorityQueue.priorityTable.name["mc_sr_rake"] = L["Rake with Mangle & SR"]
PriorityQueue.priorityTable.icon["mc_sr_rake"] = C["Rake Icon"]
PriorityQueue.priorityTable.test["mc_sr_rake"] = 
	function ()
		return PriorityQueue:GetDebuffInfo(C["Mangle (Cat)"]) and PriorityQueue:GetBuffInfo(C["Savage Roar"]) and not PriorityQueue:GetDebuffInfo(C["Rake"]) and PriorityQueue:SpellAvailable(C["Rake"])
	end

PriorityQueue.priorityTable.name["sh"] = C["Shred"]
PriorityQueue.priorityTable.icon["sh"] = C["Shred Icon"]
PriorityQueue.priorityTable.test["sh"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Shred"])
	end

PriorityQueue.priorityTable.name["4cp_sr"] = L["Savage Roar with 4CP"]
PriorityQueue.priorityTable.icon["4cp_sr"] = C["Savage Roar Icon"]
PriorityQueue.priorityTable.test["4cp_sr"] = 
	function ()
		local buff, duration = PriorityQueue:GetBuffInfo(C["Savage Roar"])
		
		return (not buff or duration < 4) and GetComboPoints("player", "target") >= 4 and PriorityQueue:SpellAvailable(C["Savage Roar"])
	end

PriorityQueue.priorityTable.name["5cp_rip"] = L["Rip at 5CP"]
PriorityQueue.priorityTable.icon["5cp_rip"] = C["Rip Icon"]
PriorityQueue.priorityTable.test["5cp_rip"] = 
	function ()
		local debuff, duration = PriorityQueue:GetBuffInfo(C["Rip"]);
		return (not debuff or duration < 4) and PriorityQueue:SpellAvailable(C["Rip"]) and GetComboPoints("player", "target") >= 5
	end

PriorityQueue.priorityTable.name["4cp_rip"] = L["Rip at 4CP"]
PriorityQueue.priorityTable.icon["4cp_rip"] = C["Rip Icon"]
PriorityQueue.priorityTable.test["4cp_rip"] = 
	function () 
		local debuff, duration = PriorityQueue:GetBuffInfo(C["Rip"]);
		return (not debuff or duration < 4) and PriorityQueue:SpellAvailable(C["Rip"]) and GetComboPoints("player", "target") >= 4
	end

PriorityQueue.priorityTable.name["4cp_rip_fb"] = L["Ferocious Bite with Rip"]
PriorityQueue.priorityTable.icon["4cp_rip_fb"] = C["Ferocious Bite Icon"]
PriorityQueue.priorityTable.test["4cp_rip_fb"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Ferocious Bite"]) and GetComboPoints("player", "target") >= 4 and PriorityQueue:GetDebuffInfo(C["Rip"])
	end

PriorityQueue.priorityTable.name["4cp_fb"] = L["Ferocious Bite at 4CP"]
PriorityQueue.priorityTable.icon["4cp_fb"] = C["Ferocious Bite Icon"]
PriorityQueue.priorityTable.test["4cp_fb"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Ferocious Bite"]) and GetComboPoints("player", "target") >= 4
	end

PriorityQueue.priorityTable.name["5cp_fb"] = L["Ferocious Bite at 5CP"]
PriorityQueue.priorityTable.icon["5cp_fb"] = C["Ferocious Bite Icon"]
PriorityQueue.priorityTable.test["5cp_fb"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Ferocious Bite"]) and GetComboPoints("player", "target") >= 5
	end