if not PriorityQueue then return end

if select(2, UnitClass('player')) ~= "WARRIOR" then
	return
end

local L = LibStub("AceLocale-3.0"):GetLocale("PriorityQueue")
local C = PriorityQueue.constants -- Defined in PriorityQueue LUA no locale needed.

-- Abilities:
---- Common:
C["Execute"], _, C["Execute Icon"] = GetSpellInfo(5308)
C["Heroic Strike"], _, C["Heroic Strike Icon"] = GetSpellInfo(78)

---- Prot:
C["Shield Slam"], _, C["Shield Slam Icon"] = GetSpellInfo(23922)
C["Revenge"], _, C["Revenge Icon"] = GetSpellInfo(6572)
C["Devastate"], _, C["Devastate Icon"] = GetSpellInfo(20243)
C["Concussion Blow"], _, C["Concussion Blow"] = GetSpellInfo(12809)
C["Shockwave"], _, C["Shockwave Icon"] = GetSpellInfo(46968)

---- Fury:
C["Bloodthirst"], _, C["Bloodthirst Icon"] = GetSpellInfo(23881);
C["Slam"], _, C["Slam Icon"] = GetSpellInfo(1464)
C["Whirlwind"], _, C["Whirlwind Icon"] = GetSpellInfo(1680)

-- Procs/Buffs:
C["Slam!"] = GetSpellInfo(46916);

---------------------------
-- Warrior Priorities
---------------------------

function PriorityQueue:GetWarriorPriorityDefaults()
	-- need a function to work out spec for now fixed values
	self.presets.priorities.name["Fury"] =  L["Fury"]
	self.presets.priorities.list["Fury"] = { "ww", "slam",  "bt",  "ex", "hs60", "none", "none", "none", "none", "none" }
	self.presets.priorities.name["Protection"] =  L["Protection"]
	self.presets.priorities.list["Protection"] = { "ss", "rev",  "dev",  "cb", "sw", "none", "none", "none", "none", "none" }
	self.presets.default = "Protection"
end

-- Common priorities:
PriorityQueue.priorityTable.name["ex"] = C["Execute"]
PriorityQueue.priorityTable.icon["ex"] = C["Execute Icon"]
PriorityQueue.priorityTable.test["ex"] = 
	function () 
		local unithealth = 100 * UnitHealth("target") / UnitHealthMax("target")
		if unithealth <= 20 then
			return PriorityQueue:SpellAvailable(C["Execute"])
		end
		return false
	end

PriorityQueue.priorityTable.name["hs"] = C["Heroic Strike"]
PriorityQueue.priorityTable.icon["hs"] = C["Heroic Strike Icon"]
PriorityQueue.priorityTable.test["hs"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Heroic Strike"]) 
	end

PriorityQueue.priorityTable.name["hs60"] = L["Heroic Strike if rage >= 60"]
PriorityQueue.priorityTable.icon["hs60"] = C["Heroic Strike Icon"]
PriorityQueue.priorityTable.test["hs60"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Heroic Strike"]) and UnitPower("player") >= 60
	end

-- Prot-specific:
PriorityQueue.priorityTable.name["ss"] = C["Shield Slam"]
PriorityQueue.priorityTable.icon["ss"] = C["Shield Slam Icon"]
PriorityQueue.priorityTable.test["ss"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Shield Slam"]) 
	end 

PriorityQueue.priorityTable.name["rev"] = C["Revenge"]
PriorityQueue.priorityTable.icon["rev"] = C["Revenge Icon"]
PriorityQueue.priorityTable.test["rev"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Revenge"]) 
	end 

PriorityQueue.priorityTable.name["dev"] = C["Devastate"]
PriorityQueue.priorityTable.icon["dev"] = C["Devastate Icon"]
PriorityQueue.priorityTable.test["dev"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Devastate"]) 
	end 

PriorityQueue.priorityTable.name["cb"] = C["Concussion Blow"]
PriorityQueue.priorityTable.icon["cb"] = C["Concussion Blow Icon"]
PriorityQueue.priorityTable.test["cb"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Concussion Blow"]) 
	end 
	
PriorityQueue.priorityTable.name["sw"] = C["Shockwave"]
PriorityQueue.priorityTable.icon["sw"] = C["Shockwave Icon"]
PriorityQueue.priorityTable.test["sw"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Shockwave"]) 
	end

-- Fury-specific:
PriorityQueue.priorityTable.name["bt"] = C["Bloodthirst"]
PriorityQueue.priorityTable.icon["bt"] = C["Bloodthirst Icon"]
PriorityQueue.priorityTable.test["bt"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Bloodthirst"]) 
	end 

PriorityQueue.priorityTable.name["ww"] = C["Whirlwind"]
PriorityQueue.priorityTable.icon["ww"] = C["Whirlwind Icon"]
PriorityQueue.priorityTable.test["ww"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Whirlwind"]) 
	end

PriorityQueue.priorityTable.name["slam"] = C["Slam"]
PriorityQueue.priorityTable.icon["slam"] = C["Slam Icon"]
PriorityQueue.priorityTable.test["slam"] = 
	function () 
		return PriorityQueue:SpellAvailable(C["Slam"]) and PriorityQueue:GetBuffInfo(C["Slam!"])
	end 